@@ -11,6 +11,11 @@ import re
 
 apiKeys = {
     "cronos": [],
+    "opt":[
+        "M88PMFFAS2KAAT71X6UP491MHWA9VMU6V6",
+        "NW3G4BUUVFD1D1YRFQSYGDWFZ81KY9K758",
+        "2CEAVWSQMGTSTA4A6QS95NHYBPU6SDWMMK"
+    ],
     "heco": [
         "JCTU517KN68FM9APHJWPQ7FVPHKFIAUCZB",
         "GWB1A9WKKFVQCE572YH8TA6CHRNVE42R41",
@@ -176,6 +181,7 @@ defaultFolder = "contract"
 
 reqUrl = {
     "heco": "https://api.hecoinfo.com/api?module=contract&action=getsourcecode&address=",
+    "opt": "https://api-optimistic.etherscan.io/api?module=contract&action=getsourcecode&address=",
     "eth": "https://api.etherscan.io/api?module=contract&action=getsourcecode&address=",
     "bsc": "https://api.bscscan.com/api?module=contract&action=getsourcecode&address=",
     "fantom": "https://api.ftmscan.com/api?module=contract&action=getsourcecode&address=",
@@ -268,7 +274,7 @@ proxyContract = {}
 
 def _argparse():
     parser = argparse.ArgumentParser(
-        description="To get contract source code. \n\nSupport network: \nHeco|ETH|BSC|Fantom|Poly|AVAX|ARBI|Tron\nCronos|moonbeam|moonriver|boba|okex\navax-testnet|arbi-testnet|poly-testnet\nbsc-testnet|heco-testnet|ftm-testnet\nGoerli|Kovan|Rinkeby|Ropsten\nmoonbase|boba-testnet\n\nGet code by tx only supports:\nBSC|ETH|BOBA|ARBI|HECO",
+        description="To get contract source code. \n\nSupport network: \nHeco|ETH|BSC|Fantom|Poly|AVAX|ARBI|Tron\nCronos|moonbeam|moonriver|boba|okex|opt\navax-testnet|arbi-testnet|poly-testnet\nbsc-testnet|heco-testnet|ftm-testnet\nGoerli|Kovan|Rinkeby|Ropsten\nmoonbase|boba-testnet\n\nGet code by tx only supports:\nBSC|ETH|BOBA|ARBI|HECO",
         formatter_class=RawTextHelpFormatter)
     parser.add_argument('-i', default='', dest='inputFile', help='Input file path including contract addresses.')
     parser.add_argument('-o', default='', dest='outputFolder', help='Choose a folder to export.')
